crypto/weakcryptospi/source/bigint/mont.cpp
changeset 29 ece3df019add
parent 19 cd501b96611d
--- a/crypto/weakcryptospi/source/bigint/mont.cpp	Fri Nov 06 13:21:00 2009 +0200
+++ b/crypto/weakcryptospi/source/bigint/mont.cpp	Tue Nov 24 09:06:03 2009 +0200
@@ -56,7 +56,7 @@
 	{
 	}
 
-TInteger& CMontgomeryStructure::ConvertIn(TInteger& aInteger) const
+TInteger& CMontgomeryStructure::ConvertInL(TInteger& aInteger) const
 	{
 	aInteger <<= WordsToBits(iModulus.Size());
 	aInteger %= iModulus;
@@ -99,7 +99,7 @@
 	{
 	RInteger a = RInteger::NewL(aA);
 	CleanupStack::PushL(a);
-	DoSquareL(iResult, ConvertIn(a));
+	DoSquareL(iResult, ConvertInL(a));
 	ConvertOutL(iResult);
 	CleanupStack::PopAndDestroy(&a);
 	return iResult;
@@ -138,8 +138,8 @@
 	// g2 <- g^2
 	RInteger g2 = RInteger::NewL(aBase);
 	CleanupStack::PushL(g2);
-	ConvertIn(g2);
-	//ConvertIn can shrink g2, because we call DoSquare on g2, g2 must be the same size as the modulus
+	ConvertInL(g2);
+	//ConvertInL can shrink g2, because we call DoSquare on g2, g2 must be the same size as the modulus
 	g2.CleanGrowL(iModulus.Size());
 	RInteger g1 = RInteger::NewL(g2);
 	CleanupStack::PushL(g1);
@@ -164,7 +164,7 @@
 	// 2 A <- 1, i <- t
 	RInteger temp = RInteger::NewL(TInteger::One());
 	CleanupStack::PushL(temp);
-	ConvertIn(temp);
+	ConvertInL(temp);
 
 	RInteger& A = iResult;
 	//Set A to one converted in for this modulus without changing the memory size of A (iResult)
@@ -214,7 +214,7 @@
 	{
 	RInteger temp = RInteger::NewL(aInteger);
 	CleanupStack::PushL(temp);
-	ConvertIn(temp);
+	ConvertInL(temp);
 	iResult.CopyL(ConvertOutL(temp), EFalse);
 	CleanupStack::PopAndDestroy(&temp);
 	return iResult;
@@ -235,7 +235,7 @@
 	CleanupStack::PushL(a);
 	RInteger b = RInteger::NewL(aB);
 	CleanupStack::PushL(b);
-	DoMultiplyL(iResult, ConvertIn(a), ConvertIn(b));
+	DoMultiplyL(iResult, ConvertInL(a), ConvertInL(b));
 	ConvertOutL(iResult);
 	CleanupStack::PopAndDestroy(&b); 
 	CleanupStack::PopAndDestroy(&a);